<?php
defined('TYPO3_MODE') or die();

// Add a "related pages" field to demonstrate select-type fields with tree rendering
// USAGE: TCA Reference > $TCA array reference > ['columns'][field name]['config'] / TYPE: "select"
// https://docs.typo3.org/typo3cms/TCAReference/Reference/Columns/Select/Index.html#render-the-general-record-storage-page-selector-as-a-tree-of-page
$temporaryColumn = [
    'tx_examples_related_pages' => [
        'exclude' => 0,
        'label' => 'LLL:EXT:examples/Resources/Private/Language/locallang_db.xlf:pages.tx_examples_related_pages',
        'config' => [
            'type' => 'select',
            'foreign_table' => 'pages',
            'size' => 10,
            'renderMode' => 'tree',
            'treeConfig' => [
                'expandAll' => true,
                'parentField' => 'pid',
                'appearance' => [
                    'showHeader' => true,
                ],
            ],
        ],
    ],
];
\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addTCAcolumns('pages', $temporaryColumn);
\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addFieldsToPalette(
    'pages',
    'media',
    '--linebreak--,tx_examples_related_pages',
    'after:media'
);

// Add an extra categories selection field to the pages table
\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::makeCategorizable(
    'examples',
    'pages',
    // Do not use the default field name ("categories"), which is already used
    'tx_examples_cats',
    [
        // Set a custom label
        'label' => 'LLL:EXT:examples/Resources/Private/Language/locallang.xlf:additional_categories',
        // This field should not be an exclude-field
        'exclude' => false,
        // Override generic configuration, e.g. sort by title rather than by sorting
        'fieldConfiguration' => [
            'foreign_table_where' => ' AND sys_category.sys_language_uid IN (-1, 0) ORDER BY sys_category.title ASC',
        ],
    ]
);

// SAME as registered in ext_tables.php
$customPageDoktype = 116;
$customIconClass = 'tx_examples-archive-page';

// Add the new doktype to the page type selector
$GLOBALS['TCA']['pages']['columns']['doktype']['config']['items'][] = [
    'LLL:EXT:examples/Resources/Private/Language/locallang.xlf:archive_page_type',
    $customPageDoktype,
    $customIconClass,
];
// Also add the new doktype to the page language overlays type selector (so that translations can inherit the same type)
$GLOBALS['TCA']['pages_language_overlay']['columns']['doktype']['config']['items'][] = [
    'LLL:EXT:examples/Resources/Private/Language/locallang.xlf:archive_page_type',
    $customPageDoktype,
    $customIconClass,
];
// Add the icon to the icon class configuration
$GLOBALS['TCA']['pages']['ctrl']['typeicon_classes'][$customPageDoktype] = $customIconClass;
// Add the new doktype to the list of types available from the new page menu at the top of the page tree
\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addUserTSConfig(
    'options.pageTree.doktypesToShowInNewPageDragArea := addToList(' . $customPageDoktype . ')'
);
